@@ -41,7 +41,7 @@ class Google(object):
         redirect_uri='urn:ietf:wg:oauth:2.0:oob',
         scopes=[],
         service_account_email=None,
-        service_account_file='service_account.json',
+        service_account_file=None,
         service_account_info=None,
         subject=None,
         verbose=False,
@@ -64,6 +64,8 @@ class Google(object):
         self.scopes = scopes
 
         # service account authentication (json/p12)
+        if not service_account_file:
+            service_account_file = os.environ.get("GOOGLE_APPLICATION_CREDENTIALS")
         self.service_account_file = service_account_file
         self.service_account_info = service_account_info
         self.subject = subject
