@@ -10,7 +10,7 @@ class Gmail(Base):
 
     def __init__(self, credentials):
         """Initialize a class instance."""
-        self.gmail = build('gmail', 'v1', credentials=credentials)
+        self.gmail = build('gmail', 'v1', credentials=credentials, cache_discovery=False)
 
     def add_delegate(self, userId, delegate):
         """Add a delegate for a user."""
