@@ -10,7 +10,7 @@ class Licensing(Base):
 
     def __init__(self, credentials, inventory={}):
         """Initialize a class instance."""
-        self.licensing = build('licensing', 'v1', credentials=credentials)
+        self.licensing = build('licensing', 'v1', credentials=credentials, cache_discovery=False)
 
         # hard-coded license inventory
         self.inventory = inventory
