@@ -11,7 +11,7 @@ class People(Base):
     def __init__(self, credentials):
         """Initialize a class instance."""
         # build a connection to the people API
-        self.people = build('people', 'v1', credentials=credentials)
+        self.people = build('people', 'v1', credentials=credentials, cache_discovery=False)
 
         # define default list of personFields
         self.person_fields = [
